# Generated by Django 2.0.8 on 2018-11-06 15:29

import datasources.models
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


def datasource_permissions_forward(apps, schema_editor):
    """
    Copy user permissions from old group-based form to new linking-table form.
    """
    DataSource = apps.get_model('datasources', 'DataSource')
    UserPermissionLink = apps.get_model('datasources', 'UserPermissionLink')

    for data_source in DataSource.objects.all():
        if data_source.access_control:
            for user in data_source.users_group.user_set.all():
                UserPermissionLink.objects.get_or_create(
                    user=user,
                    datasource=data_source,
                    granted=datasources.models.UserPermissionLevels.VIEW
                )

            for user in data_source.users_group_requested.user_set.all():
                link, created = UserPermissionLink.objects.get_or_create(
                    user=user,
                    datasource=data_source,
                )
                if not link.granted >= datasources.models.UserPermissionLevels.VIEW:
                    link.requested = datasources.models.UserPermissionLevels.VIEW
                    link.save()


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('datasources', '0010_datasource_auth_method'),
    ]

    operations = [
        migrations.CreateModel(
            name='UserPermissionLink',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('granted', models.IntegerField(choices=[('NONE', 0), ('VIEW', 1), ('META', 2), ('DATA', 3), ('PROV', 4)], default=datasources.models.UserPermissionLevels(0))),
                ('requested', models.IntegerField(choices=[('NONE', 0), ('VIEW', 1), ('META', 2), ('DATA', 3), ('PROV', 4)], default=datasources.models.UserPermissionLevels(0))),
            ],
        ),
        migrations.AddField(
            model_name='userpermissionlink',
            name='datasource',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='datasources.DataSource'),
        ),
        migrations.AddField(
            model_name='userpermissionlink',
            name='user',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='datasource',
            name='users',
            field=models.ManyToManyField(through='datasources.UserPermissionLink', to=settings.AUTH_USER_MODEL),
        ),
        migrations.RunPython(datasource_permissions_forward),
        migrations.RemoveField(
            model_name='datasource',
            name='users_group',
        ),
        migrations.RemoveField(
            model_name='datasource',
            name='users_group_requested',
        ),
    ]
